@@ -1,7 +1,11 @@
 import django
-from wagtail import __version__ as WAGTAIL_VERSION
 from pkg_resources import parse_version
 
+try:
+    from wagtail import __version__ as WAGTAIL_VERSION
+except ImportError:
+    WAGTAIL_VERSION = False
+
 
 DJANGO_VERSION_TRANSLATION_UGETTEXT = False
 if parse_version(django.get_version()) < parse_version('2.0.0'):
